measuretools.scale_measure_denominator_and_adjust_measure_contents
==================================================================

.. autofunction:: abjad.tools.measuretools.scale_measure_denominator_and_adjust_measure_contents.scale_measure_denominator_and_adjust_measure_contents
